function eyes = chooseEyes(subjects)
% chooseEyes - Choose an eye per subject randomly
%
% eyes = chooseEyes(subjects)
%
% Input arguments:
%   subjects: subject table
%
% Output arguments:
%   eyes: cell array indicating either left (OS) or right (OD) for each
%   subject
%
% When a subject only has one eye (due to exclusion) that eye is selected,
% otherwise an eye is chosen randomly
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department

eyes = cell(size(subjects,1),1);

hasOS = (subjects.raster_OS == 1) & (subjects.star_OS == 1);
hasOD = (subjects.raster_OD == 1) & (subjects.star_OD == 1);

% Subjects with only OS
eyes(hasOS & ~hasOD) = {'OS'};

% Subjects with only OD
eyes(~hasOS & hasOD) = {'OD'};

% Subjects with both eyes (choose randomly)
rng(0); % seed
hasBoth = find(hasOS & hasOD);
selectedEye = randi(2,1,length(hasBoth));
for n=1:length(hasBoth)
    if selectedEye(n) == 1
        eyes(hasBoth(n)) = {'OS'};
    elseif selectedEye(n) == 2
        eyes(hasBoth(n)) = {'OD'};
    end
end

