function y = equationLiu(x,a,f,g,lambda,mu,sigma)
% equationLiu - evaluate the model presented by Liu et al. (2016)
%
% y = equationLiu(x,a,f,g,lambda,mu,sigma)
%
% Input arguments:
%   a,f,g,lambda,mu,sigma: model coefficients
%   x: evaluating point
%
% Output arguments:
%   y: evaluated value
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department

G = exp(-(x-mu).^2/sigma^2);
centre = (x>=(mu-lambda/2) & x<=(mu+lambda/2));

G1 = G;
G1(centre) = max(G);
G2 = g - (a*G1+f*x); 

y = G2;