function Combos = getCombos(varargin)
% getCombos - generate a struct array with all combination of cell array 
% elements 
%
% Combos = getCombos(varargin)
%
% Input arguments:
%   varargin: cell array with strings
%
% Output arguments:
%   Combos: struct array with combinations
%
% Based in:
% From https://stackoverflow.com/questions/8492277/matlab-combinations-of-an-arbitrary-number-of-cell-arrays
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department

sizeVec = cellfun('prodofsize', varargin);
indices = fliplr(arrayfun(@(n) {1:n}, sizeVec));
[indices{:}] = ndgrid(indices{:});
combMat = cellfun(@(c,i) {reshape(c(i(:)), [], 1)}, ...
                varargin, fliplr(indices));                       
combMat = [combMat{:}];

nCombos = size(combMat);

for n=1:nCombos
    for id = 1:nargin
       Combos(n).(inputname(id)) = combMat{n,id};
    end
end

